/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2013-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <Q3TextStream>
#include <iostream>
#include "sqlrefpolicy_cleanup.h"

using namespace std;

//default constructor
SqlrefpolicyCleanup::SqlrefpolicyCleanup(QFile)
{
	cout << "test" << endl;
	//change path as you wish.
	/////////////////////////////////////////////////////////////
	path = "./";
	path_to_be_written = "target_domain_sqlite_final3.txt";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();

	file_w.setName(path_to_be_written);
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	files = dir.entryList("target_domain_sqlite_final2.txt");
	colon = ":";
	/////////////////////////////////////////////////////////////
	/*
	it_d = files.begin();
	while(it_d != files.end()){
		name = *it_d;
		file_interface_name = dir_name + forward_slash + name;
		QFile file( file_interface_name );
		if ( file.open( QIODevice::ReadOnly ) ) {
			Q3TextStream stream( &file );
			////////////////////////////////////////////
			lines.clear();
			line_analized.clear();
        		QStringList list2;
         		QString check_str;
         		QString av_str;
			int av_int;
			while ( !stream.atEnd() ) {
				line_analized = stream.readLine(); // line of text excluding 'n'
				if(line_analized.contains(",", Qt::CaseInsensitive)){
					//list2 = line_analized.split(" ");
					list2 = line_analized.split(",", QString::SkipEmptyParts);	
					for (int i = 0; i < list2.size(); ++i){
          					check_str=list2.value(i);
  						if(check_str.startsWith("{")== true){
 							av_int = i+1;		
							log_str_access_vector=list2.value(av_int);
						}
  						if(check_str.startsWith("tclass")== true){
							log_str_tclass=list2.value(i);
							log_str_tclass = log_str_tclass.section('=', 1, 1);
						}
  						if(check_str.startsWith("tcontext")== true){
							log_str_tcontext=list2.value(i);
							log_str_tcontext = log_str_tcontext.section('=', 1, 1);
							log_str_tcontext = log_str_tcontext.section(':', 2, 2);
						}
  						if(check_str.startsWith("scontext")== true){
							log_str_scontext=list2.value(i);
							log_str_scontext = log_str_scontext.section('=', 1, 1);
							log_str_scontext = log_str_scontext.section(':', 2, 2);
						}
					}
					//lines += log_str_scontext + "," + log_str_tcontext + "," + log_str_tclass + "," + log_str_access_vector;
					lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";

				}
			}
			//lines.removeDuplicates();
			//lines.sort();
			lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
		}
		file.close();
		++it_d;
	}
	*/
	//lines += "Alert!! <font color="purple">" + log_str_scontext + " </font> wants to <font color="red"> " + log_str_access_vector + "  </font><font color="blue"> " + log_str_tclass + " </font> in <font color="green">" + log_str_tcontext + " </font> Refpolicy Analyzer will help you. <br />";
	
	lines += "Alert!!";
	//writing to file
	//
	
        QFile* file = new QFile();
        QDir::setCurrent("./");
        file->setFileName("target_domain_sqlite_final2.txt");
        file->open(QIODevice::ReadWrite);
        QString strFile1(file->readAll());
        file->close();
        QTextEdit* edit = new QTextEdit();
        edit->setFixedSize(800,500);
        edit->setPlainText(strFile1);
        edit->setWindowTitle("QFile Open&Read File");

	if (file_w.exists()) {
		file_w.remove();
	}
	if ( file_w.open( QIODevice::WriteOnly | QIODevice::Append ) ) {
		Q3TextStream stream_w( &file_w );
		for ( it = lines.begin(); it != lines.end(); ++it ){
			stream_w << *it;
		}
	}
	file_w.close();
	//sqlrefpolicy_select(lines_log_str_scontext,lines_log_str_tcontext,lines_log_str_tclass,lines_log_str_access_vector);
	lines.clear();
	lines_log_str_scontext.clear();
	lines_log_str_tcontext.clear();
	lines_log_str_tclass.clear();
	lines_log_str_access_vector.clear();

	edit->show();
}//end
